summaryrefslogtreecommitdiffstatshomepage
path: root/core/tests/Drupal/FunctionalTests/BrowserTestBaseTest.php
diff options
context:
space:
mode:
Diffstat (limited to 'core/tests/Drupal/FunctionalTests/BrowserTestBaseTest.php')
-rw-r--r--core/tests/Drupal/FunctionalTests/BrowserTestBaseTest.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/core/tests/Drupal/FunctionalTests/BrowserTestBaseTest.php b/core/tests/Drupal/FunctionalTests/BrowserTestBaseTest.php
index 956e304a9d4..54bb662e211 100644
--- a/core/tests/Drupal/FunctionalTests/BrowserTestBaseTest.php
+++ b/core/tests/Drupal/FunctionalTests/BrowserTestBaseTest.php
@@ -482,8 +482,8 @@ class BrowserTestBaseTest extends BrowserTestBase {
$htaccess_filename = $this->tempFilesDirectory . '/.htaccess';
$this->assertFileExists($htaccess_filename);
- // Ensure the update module is not installed.
- $this->assertFalse(\Drupal::moduleHandler()->moduleExists('update'), 'The Update module is not installed.');
+ // Ensure the Update Status module is not installed.
+ $this->assertFalse(\Drupal::moduleHandler()->moduleExists('update'), 'The Update Status module should not be installed.');
}
/**